Skip to main content

ifcimglib

Install

Run:

pip install .

to install this package.

How to use

cif2lmdb can be used as follows:

Usage: cif2lmdb [OPTIONS] CIF

Options:
  --output FILE       Output filename. If not set, cif-filename is taken with
                      lmdb extension.

  --channels INTEGER  Images from these channels will be extracted. Default is
                      to extract all. 1-based index.

  --names TEXT        Names to assign to channels.
  --debug             Show debugging information. Limits output to 100 first
                      cells.

  --overwrite         Overwrite lmdb if it exists.
  --targets-npy FILE  Numpy binary file containing targets.
  --skip-npy FILE     Numpy binary file containing instances to be skipped.
  --help              Show this message and exit.

Here is an example command:

cif2lmdb --channels 1 --channels 6 --channels 9 --names BF --names SSC --names BF2 --output tmp.lmdb --debug --overwrite input.cif

It takes input.cif as input and outputs output.lmdb, an lmdb-file containing 100 (see debug flag) 3-channel images with names BF, SSC and BF2.

Please see the imglmdb.ipynb notebook for usage examples of the imglmdb package.

Docker

docker badge

Docker images are available for cif2lmdb (tag cif2lmdb), the jupyter lab environment (tag jupyter-lab-env), and the notebooks in this repository (tag notebooks).

For using cif2lmdb, run:

docker run --rm -v /path/to/data/dir:/data maximlippeveld/ifcimglib:cif2lmdb [OPTIONS] /data/example.cif

For using the jupyter environment, run:

docker run --it -v /path/to/data/dir:/data -v /path/to/your/code/dir:/app -p [your-port]:8888 maximlippeveld/ifcimglib:jupyter-lab-env

Fur using the notebooks in this repository, run:

docker run --it -v /path/to/data/dir:/data -p [your-port]:8888 maximlippeveld/ifcimglib:notebooks

Metadata

Release files for ifcimglib 0.1.3

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for ifcimglib 0.1.3
File Size Uploaded
ifcimglib-0.1.3.tar.gz 16.9 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for ifcimglib 0.1.3
File Interpreter ABI Platform
ifcimglib-0.1.3-py3-none-any.whl Python 3 none any Details

Total release size: 34.1 kB

Release files / ifcimglib-0.1.3.tar.gz

Download URL ifcimglib-0.1.3.tar.gz
Size 16.9 kB
Tags Source
SHA-256 checksum
How to use checksums
1fb2eccc4c3119d2e358e3b5ea99cff0d978b6810c58611e321f24681cf3eddd
BLAKE2b-256 checksum
How to use checksums
6bda13756017563e9e65df3326968ef65317fd2f3159258b4c7011fb6414436c
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.4.1 importlib_metadata/4.6.1 pkginfo/1.7.0 requests/2.25.1 requests-toolbelt/0.9.1 tqdm/4.61.2 CPython/3.8.10

Release files / ifcimglib-0.1.3-py3-none-any.whl

Download URL ifcimglib-0.1.3-py3-none-any.whl
Size 17.2 kB
Tags Python 3
SHA-256 checksum
How to use checksums
d9c26cf78ac65ca8b01a5d8c4e8410b3af70566441d3eed71227b6b7eff46330
BLAKE2b-256 checksum
How to use checksums
fbcc23253b856772aee49a2d3b40b0f840ed75a35405f49b585deaba3f9a69be
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.4.1 importlib_metadata/4.6.1 pkginfo/1.7.0 requests/2.25.1 requests-toolbelt/0.9.1 tqdm/4.61.2 CPython/3.8.10

Release history Release notifications | RSS feed

This release

0.1.3 This release

2 release files

0.1.2

2 release files

0.1.1

2 release files

0.1.0

2 release files

0.0.3

2 release files

0.0.2

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page